@@ -142,7 +142,7 @@ where
                         data.get_unchecked(3 * k + 1).to_f64().unwrap(),
                     );
                     (q1, (q2_l + q2_r) / 2., q3)
-                }
+                },
                 // Let data = {x_i}_{i=0..4k+3} where k is positive integer.
                 // Median q2 = x_{2k+1}.
                 // If we divide data other than q2 into two parts {x_i < q2}
@@ -155,7 +155,7 @@ where
                         data.get_unchecked(3 * k + 2).to_f64().unwrap(),
                     );
                     (q1, q2, q3)
-                }
+                },
             }
         }
     })
@@ -175,9 +175,9 @@ where
     let (mut mode, mut next) = (None, None);
     let (mut mode_count, mut next_count) = (0usize, 0usize);
     for x in it {
-        if mode.as_ref().map(|y| y == &x).unwrap_or(false) {
+        if mode.as_ref().map_or(false, |y| y == &x) {
             mode_count += 1;
-        } else if next.as_ref().map(|y| y == &x).unwrap_or(false) {
+        } else if next.as_ref().map_or(false, |y| y == &x) {
             next_count += 1;
         } else {
             next = Some(x);
